"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.queryFunctionTemplates = exports.updateFunctionTemplate = exports.createFunctionTemplate = void 0;
const field_mask_1 = require("@wix/sdk-runtime/transformations/field-mask");
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
function resolveWixFunctionsTemplatesV1FunctionTemplatesUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/_api/function-templates-api',
                destPath: '',
            },
        ],
        'dev._base_domain_': [
            {
                srcPath: '/_api/function-templates-api',
                destPath: '',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/api/functions/v1/templates',
                destPath: '/v1/templates',
            },
        ],
    };
    return (0, rest_modules_1.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_functions_function-templates';
/** Creates a FunctionTemplate */
function createFunctionTemplate(payload) {
    function __createFunctionTemplate({ host }) {
        const metadata = {
            entityFqdn: 'wix.functions.templates.v1.function_template',
            method: 'POST',
            methodFqn: 'wix.functions.templates.v1.FunctionTemplates.CreateFunctionTemplate',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsTemplatesV1FunctionTemplatesUrl({
                protoPath: '/v1/templates',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __createFunctionTemplate;
}
exports.createFunctionTemplate = createFunctionTemplate;
/** Updates a FunctionTemplate. */
function updateFunctionTemplate(payload) {
    function __updateFunctionTemplate({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: field_mask_1.transformSDKFieldMaskToRESTFieldMask,
                paths: [{ path: 'fieldMask' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.functions.templates.v1.function_template',
            method: 'PATCH',
            methodFqn: 'wix.functions.templates.v1.FunctionTemplates.UpdateFunctionTemplate',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsTemplatesV1FunctionTemplatesUrl({
                protoPath: '/v1/templates/{functionTemplate.id}',
                data: serializedData,
                host,
            }),
            data: serializedData,
        };
        return metadata;
    }
    return __updateFunctionTemplate;
}
exports.updateFunctionTemplate = updateFunctionTemplate;
/** Retrieves a list of FunctionTemplates, should  we support paging, filtering, and sorting in this api? */
function queryFunctionTemplates(payload) {
    function __queryFunctionTemplates({ host }) {
        const metadata = {
            entityFqdn: 'wix.functions.templates.v1.function_template',
            method: 'POST',
            methodFqn: 'wix.functions.templates.v1.FunctionTemplates.QueryFunctionTemplates',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsTemplatesV1FunctionTemplatesUrl({
                protoPath: '/v1/templates/query',
                data: payload,
                host,
            }),
            data: payload,
            fallback: [
                {
                    method: 'POST',
                    url: resolveWixFunctionsTemplatesV1FunctionTemplatesUrl({
                        protoPath: '/v1/templates/query',
                        data: payload,
                        host,
                    }),
                    data: payload,
                },
            ],
        };
        return metadata;
    }
    return __queryFunctionTemplates;
}
exports.queryFunctionTemplates = queryFunctionTemplates;
//# sourceMappingURL=functions-templates-v1-function-template-function-templates.http.js.map