"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.queryFunctionTemplates = exports.updateFunctionTemplate = exports.createFunctionTemplate = exports.WebhookIdentityType = exports.SortOrder = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const query_builder_1 = require("@wix/sdk-runtime/query-builder");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixFunctionsTemplatesV1FunctionTemplate = __importStar(require("./functions-templates-v1-function-template-function-templates.http.js"));
var SortOrder;
(function (SortOrder) {
    SortOrder["ASC"] = "ASC";
    SortOrder["DESC"] = "DESC";
})(SortOrder || (exports.SortOrder = SortOrder = {}));
var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (exports.WebhookIdentityType = WebhookIdentityType = {}));
/**
 * Creates a FunctionTemplate
 * @param functionTemplate - FunctionTemplate to be created.
 * @public
 * @documentationMaturity preview
 * @requiredField functionTemplate
 * @returns The created FunctionTemplate.
 * @fqn wix.functions.templates.v1.FunctionTemplates.CreateFunctionTemplate
 */
async function createFunctionTemplate(functionTemplate) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        functionTemplate: functionTemplate,
    });
    const reqOpts = ambassadorWixFunctionsTemplatesV1FunctionTemplate.createFunctionTemplate(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data)
            ?.functionTemplate;
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { functionTemplate: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['functionTemplate']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.createFunctionTemplate = createFunctionTemplate;
/**
 * Updates a FunctionTemplate.
 * @param _id - dev center component id
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @requiredField functionTemplate
 * @returns Updated FunctionTemplate.
 * @fqn wix.functions.templates.v1.FunctionTemplates.UpdateFunctionTemplate
 */
async function updateFunctionTemplate(_id, functionTemplate) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        functionTemplate: { ...functionTemplate, id: _id },
    });
    const reqOpts = ambassadorWixFunctionsTemplatesV1FunctionTemplate.updateFunctionTemplate(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data)
            ?.functionTemplate;
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: { functionTemplate: '$[1]' },
            explicitPathsToArguments: { 'functionTemplate.id': '$[0]' },
            singleArgumentUnchanged: false,
        }, ['_id', 'functionTemplate']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.updateFunctionTemplate = updateFunctionTemplate;
/**
 * Retrieves a list of FunctionTemplates, should  we support paging, filtering, and sorting in this api?
 * @public
 * @documentationMaturity preview
 * @permissionScope Manage Functions
 * @permissionScopeId SCOPE.DC-FUNCTIONS.MANAGE-FUNCTIONS
 * @permissionId FUNCTIONS.FUNCTION_TEMPLATE_READ
 * @applicableIdentity APP
 * @fqn wix.functions.templates.v1.FunctionTemplates.QueryFunctionTemplates
 */
function queryFunctionTemplates() {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[0];
    return (0, query_builder_1.queryBuilder)({
        func: async (payload) => {
            const reqOpts = ambassadorWixFunctionsTemplatesV1FunctionTemplate.queryFunctionTemplates(payload);
            sideEffects?.onSiteCall?.();
            try {
                const result = await httpClient.request(reqOpts);
                sideEffects?.onSuccess?.(result);
                return result;
            }
            catch (err) {
                sideEffects?.onError?.(err);
                throw err;
            }
        },
        requestTransformer: (query) => {
            const args = [query, {}];
            return (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
                ...args?.[1],
                query: args?.[0],
            });
        },
        responseTransformer: ({ data, }) => {
            const transformedData = (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(data);
            return {
                items: transformedData?.functionTemplates,
                pagingMetadata: transformedData?.pagingMetadata,
            };
        },
        errorTransformer: (err) => {
            const transformedError = (0, transform_error_1.transformError)(err, {
                spreadPathsToArguments: {},
                explicitPathsToArguments: { query: '$[0]' },
                singleArgumentUnchanged: false,
            });
            throw transformedError;
        },
        pagingMethod: 'CURSOR',
        transformationPaths: {},
    });
}
exports.queryFunctionTemplates = queryFunctionTemplates;
//# sourceMappingURL=functions-templates-v1-function-template-function-templates.universal.js.map