import { transformSDKFieldMaskToRESTFieldMask } from '@wix/sdk-runtime/transformations/field-mask';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { resolveUrl } from '@wix/sdk-runtime/rest-modules';
function resolveWixFunctionsTemplatesV1FunctionTemplatesUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/_api/function-templates-api',
                destPath: '',
            },
        ],
        'dev._base_domain_': [
            {
                srcPath: '/_api/function-templates-api',
                destPath: '',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/api/functions/v1/templates',
                destPath: '/v1/templates',
            },
        ],
    };
    return resolveUrl(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_functions_function-templates';
/** Creates a FunctionTemplate */
export function createFunctionTemplate(payload) {
    function __createFunctionTemplate({ host }) {
        const metadata = {
            entityFqdn: 'wix.functions.templates.v1.function_template',
            method: 'POST',
            methodFqn: 'wix.functions.templates.v1.FunctionTemplates.CreateFunctionTemplate',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsTemplatesV1FunctionTemplatesUrl({
                protoPath: '/v1/templates',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __createFunctionTemplate;
}
/** Updates a FunctionTemplate. */
export function updateFunctionTemplate(payload) {
    function __updateFunctionTemplate({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKFieldMaskToRESTFieldMask,
                paths: [{ path: 'fieldMask' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.functions.templates.v1.function_template',
            method: 'PATCH',
            methodFqn: 'wix.functions.templates.v1.FunctionTemplates.UpdateFunctionTemplate',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsTemplatesV1FunctionTemplatesUrl({
                protoPath: '/v1/templates/{functionTemplate.id}',
                data: serializedData,
                host,
            }),
            data: serializedData,
        };
        return metadata;
    }
    return __updateFunctionTemplate;
}
/** Retrieves a list of FunctionTemplates, should  we support paging, filtering, and sorting in this api? */
export function queryFunctionTemplates(payload) {
    function __queryFunctionTemplates({ host }) {
        const metadata = {
            entityFqdn: 'wix.functions.templates.v1.function_template',
            method: 'POST',
            methodFqn: 'wix.functions.templates.v1.FunctionTemplates.QueryFunctionTemplates',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsTemplatesV1FunctionTemplatesUrl({
                protoPath: '/v1/templates/query',
                data: payload,
                host,
            }),
            data: payload,
            fallback: [
                {
                    method: 'POST',
                    url: resolveWixFunctionsTemplatesV1FunctionTemplatesUrl({
                        protoPath: '/v1/templates/query',
                        data: payload,
                        host,
                    }),
                    data: payload,
                },
            ],
        };
        return metadata;
    }
    return __queryFunctionTemplates;
}
//# sourceMappingURL=functions-templates-v1-function-template-function-templates.http.js.map