/** I suppose we not going to support data extension and tags for this api. Unless we should proxy those fields from the function. */
export interface FunctionTemplate {
    /**
     * new function id
     * @readonly
     */
    functionId?: string | null;
    /**
     * origin function id
     * @readonly
     */
    originFunctionId?: string | null;
    /**
     * Origin metasite id
     * @readonly
     */
    originMetaSiteId?: string | null;
    /** display name */
    displayName?: string | null;
    /** description */
    displayDescription?: string | null;
    /**
     * template "owner" app id
     * @readonly
     */
    appDefId?: string | null;
    /**
     * dev center component id
     * @readonly
     */
    _id?: string | null;
    /**
     * dev center component version
     * @readonly
     */
    version?: string | null;
    /**
     * function extension id
     * @readonly
     */
    functionExtensionId?: string | null;
    /** form template extension id */
    formTemplateExtensionId?: string | null;
}
export interface CreateFunctionTemplateRequest {
    /** FunctionTemplate to be created. */
    functionTemplate: FunctionTemplate;
}
export interface CreateFunctionTemplateResponse {
    /** The created FunctionTemplate. */
    functionTemplate?: FunctionTemplate;
}
export interface UpdateFunctionTemplateRequest {
    /** FunctionTemplate to be updated, may be partial. */
    functionTemplate: FunctionTemplate;
}
export interface UpdateFunctionTemplateResponse {
    /** Updated FunctionTemplate. */
    functionTemplate?: FunctionTemplate;
}
export interface QueryFunctionTemplatesRequest {
    /** WQL expression. */
    query?: CursorQuery;
}
export interface CursorQuery extends CursorQueryPagingMethodOneOf {
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
    /**
     * Filter object in the following format:
     * `"filter" : {
     * "fieldName1": "value1",
     * "fieldName2":{"$operator":"value2"}
     * }`
     * Example of operators: `$eq`, `$ne`, `$lt`, `$lte`, `$gt`, `$gte`, `$in`, `$hasSome`, `$hasAll`, `$startsWith`, `$contains`
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object in the following format:
     * `[{"fieldName":"sortField1","order":"ASC"},{"fieldName":"sortField2","order":"DESC"}]`
     */
    sort?: Sorting[];
}
/** @oneof */
export interface CursorQueryPagingMethodOneOf {
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
}
export interface Sorting {
    /** Name of the field to sort by. */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrder;
}
export declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
export interface CursorPaging {
    /** Maximum number of items to return in the results. */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     */
    cursor?: string | null;
}
export interface QueryFunctionTemplatesResponse {
    /** List of FunctionTemplates. */
    functionTemplates?: FunctionTemplate[];
    /** Paging metadata */
    pagingMetadata?: CursorPagingMetadata;
}
export interface CursorPagingMetadata {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Cursor strings that point to the next page, previous page, or both. */
    cursors?: Cursors;
    /**
     * Whether there are more pages to retrieve following the current page.
     *
     * + `true`: Another page of results can be retrieved.
     * + `false`: This is the last page.
     */
    hasNext?: boolean | null;
}
export interface Cursors {
    /** Cursor string pointing to the next page in the list of results. */
    next?: string | null;
    /** Cursor pointing to the previous page in the list of results. */
    prev?: string | null;
}
export interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /**
     * Unique event ID.
     * Allows clients to ignore duplicate webhooks.
     */
    _id?: string;
    /**
     * Assumes actions are also always typed to an entity_type
     * Example: wix.stores.catalog.product, wix.bookings.session, wix.payments.transaction
     */
    entityFqdn?: string;
    /**
     * This is top level to ease client code dispatching of messages (switch on entity_fqdn+slug)
     * This is although the created/updated/deleted notion is duplication of the oneof types
     * Example: created/updated/deleted/started/completed/email_opened
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example: 2020-04-26T13:57:50.699Z */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number defining the order of updates to the underlying entity.
     * For example, given that some entity was updated at 16:00 and than again at 16:01,
     * it is guaranteed that the sequence number of the second update is strictly higher than the first.
     * As the consumer, you can use this value to ensure that you handle messages in the correct order.
     * To do so, you will need to persist this number on your end, and compare the sequence number from the
     * message against the one you have stored. Given that the stored number is higher, you should ignore the message.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
export interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
export interface EntityCreatedEvent {
    entity?: string;
}
export interface RestoreInfo {
    deletedDate?: Date | null;
}
export interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
export interface EntityDeletedEvent {
    /** Entity that was deleted */
    deletedEntity?: string | null;
}
export interface ActionEvent {
    body?: string;
}
export interface Empty {
}
export interface MessageEnvelope {
    /** App instance ID. */
    instanceId?: string | null;
    /** Event type. */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
export interface IdentificationData extends IdentificationDataIdOneOf {
    /** ID of a site visitor that has not logged in to the site. */
    anonymousVisitorId?: string;
    /** ID of a site visitor that has logged in to the site. */
    memberId?: string;
    /** ID of a Wix user (site owner, contributor, etc.). */
    wixUserId?: string;
    /** ID of an app. */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityType;
}
/** @oneof */
export interface IdentificationDataIdOneOf {
    /** ID of a site visitor that has not logged in to the site. */
    anonymousVisitorId?: string;
    /** ID of a site visitor that has logged in to the site. */
    memberId?: string;
    /** ID of a Wix user (site owner, contributor, etc.). */
    wixUserId?: string;
    /** ID of an app. */
    appId?: string;
}
export declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
export interface BaseEventMetadata {
    /** App instance ID. */
    instanceId?: string | null;
    /** Event type. */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
}
export interface EventMetadata extends BaseEventMetadata {
    /**
     * Unique event ID.
     * Allows clients to ignore duplicate webhooks.
     */
    _id?: string;
    /**
     * Assumes actions are also always typed to an entity_type
     * Example: wix.stores.catalog.product, wix.bookings.session, wix.payments.transaction
     */
    entityFqdn?: string;
    /**
     * This is top level to ease client code dispatching of messages (switch on entity_fqdn+slug)
     * This is although the created/updated/deleted notion is duplication of the oneof types
     * Example: created/updated/deleted/started/completed/email_opened
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example: 2020-04-26T13:57:50.699Z */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number defining the order of updates to the underlying entity.
     * For example, given that some entity was updated at 16:00 and than again at 16:01,
     * it is guaranteed that the sequence number of the second update is strictly higher than the first.
     * As the consumer, you can use this value to ensure that you handle messages in the correct order.
     * To do so, you will need to persist this number on your end, and compare the sequence number from the
     * message against the one you have stored. Given that the stored number is higher, you should ignore the message.
     */
    entityEventSequence?: string | null;
}
export interface FunctionTemplateCreatedEnvelope {
    entity: FunctionTemplate;
    metadata: EventMetadata;
}
/**
 * as we don't persist data we need to think if we need domain events for this API, if yes we will need not to forget to
 * trigger the event on the right place.
 * @webhook
 * @eventType wix.functions.templates.v1.function_template_created
 * @documentationMaturity preview
 */
export declare function onFunctionTemplateCreated(handler: (event: FunctionTemplateCreatedEnvelope) => void | Promise<void>): void;
export interface FunctionTemplateUpdatedEnvelope {
    entity: FunctionTemplate;
    metadata: EventMetadata;
}
/** @webhook
 * @eventType wix.functions.templates.v1.function_template_updated
 * @documentationMaturity preview
 */
export declare function onFunctionTemplateUpdated(handler: (event: FunctionTemplateUpdatedEnvelope) => void | Promise<void>): void;
/**
 * Creates a FunctionTemplate
 * @param functionTemplate - FunctionTemplate to be created.
 * @public
 * @documentationMaturity preview
 * @requiredField functionTemplate
 * @returns The created FunctionTemplate.
 * @fqn wix.functions.templates.v1.FunctionTemplates.CreateFunctionTemplate
 */
export declare function createFunctionTemplate(functionTemplate: FunctionTemplate): Promise<FunctionTemplate>;
/**
 * Updates a FunctionTemplate.
 * @param _id - dev center component id
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @requiredField functionTemplate
 * @returns Updated FunctionTemplate.
 * @fqn wix.functions.templates.v1.FunctionTemplates.UpdateFunctionTemplate
 */
export declare function updateFunctionTemplate(_id: string | null, functionTemplate: UpdateFunctionTemplate): Promise<FunctionTemplate>;
export interface UpdateFunctionTemplate {
    /**
     * new function id
     * @readonly
     */
    functionId?: string | null;
    /**
     * origin function id
     * @readonly
     */
    originFunctionId?: string | null;
    /**
     * Origin metasite id
     * @readonly
     */
    originMetaSiteId?: string | null;
    /** display name */
    displayName?: string | null;
    /** description */
    displayDescription?: string | null;
    /**
     * template "owner" app id
     * @readonly
     */
    appDefId?: string | null;
    /**
     * dev center component id
     * @readonly
     */
    _id?: string | null;
    /**
     * dev center component version
     * @readonly
     */
    version?: string | null;
    /**
     * function extension id
     * @readonly
     */
    functionExtensionId?: string | null;
    /** form template extension id */
    formTemplateExtensionId?: string | null;
}
/**
 * Retrieves a list of FunctionTemplates, should  we support paging, filtering, and sorting in this api?
 * @public
 * @documentationMaturity preview
 * @permissionScope Manage Functions
 * @permissionScopeId SCOPE.DC-FUNCTIONS.MANAGE-FUNCTIONS
 * @permissionId FUNCTIONS.FUNCTION_TEMPLATE_READ
 * @applicableIdentity APP
 * @fqn wix.functions.templates.v1.FunctionTemplates.QueryFunctionTemplates
 */
export declare function queryFunctionTemplates(): FunctionTemplatesQueryBuilder;
interface QueryCursorResult {
    cursors: Cursors;
    hasNext: () => boolean;
    hasPrev: () => boolean;
    length: number;
    pageSize: number;
}
export interface FunctionTemplatesQueryResult extends QueryCursorResult {
    items: FunctionTemplate[];
    query: FunctionTemplatesQueryBuilder;
    next: () => Promise<FunctionTemplatesQueryResult>;
    prev: () => Promise<FunctionTemplatesQueryResult>;
}
export interface FunctionTemplatesQueryBuilder {
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    eq: (propertyName: 'appDefId' | 'functionExtensionId', value: any) => FunctionTemplatesQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    ne: (propertyName: 'appDefId' | 'functionExtensionId', value: any) => FunctionTemplatesQueryBuilder;
    /** @param propertyName - Property whose value is compared with `string`.
     * @param string - String to compare against. Case-insensitive.
     * @documentationMaturity preview
     */
    startsWith: (propertyName: 'appDefId' | 'functionExtensionId', value: string) => FunctionTemplatesQueryBuilder;
    /** @param propertyName - Property whose value is compared with `values`.
     * @param values - List of values to compare against.
     * @documentationMaturity preview
     */
    hasSome: (propertyName: 'appDefId' | 'functionExtensionId', value: any[]) => FunctionTemplatesQueryBuilder;
    /** @documentationMaturity preview */
    in: (propertyName: 'appDefId' | 'functionExtensionId', value: any) => FunctionTemplatesQueryBuilder;
    /** @documentationMaturity preview */
    exists: (propertyName: 'appDefId' | 'functionExtensionId', value: boolean) => FunctionTemplatesQueryBuilder;
    /** @param propertyNames - Properties used in the sort. To sort by multiple properties, pass properties as additional arguments.
     * @documentationMaturity preview
     */
    ascending: (...propertyNames: Array<'appDefId' | 'functionExtensionId'>) => FunctionTemplatesQueryBuilder;
    /** @param propertyNames - Properties used in the sort. To sort by multiple properties, pass properties as additional arguments.
     * @documentationMaturity preview
     */
    descending: (...propertyNames: Array<'appDefId' | 'functionExtensionId'>) => FunctionTemplatesQueryBuilder;
    /** @param limit - Number of items to return, which is also the `pageSize` of the results object.
     * @documentationMaturity preview
     */
    limit: (limit: number) => FunctionTemplatesQueryBuilder;
    /** @param cursor - A pointer to specific record
     * @documentationMaturity preview
     */
    skipTo: (cursor: string) => FunctionTemplatesQueryBuilder;
    /** @documentationMaturity preview */
    find: () => Promise<FunctionTemplatesQueryResult>;
}
export {};
